==> piwigo-2.5.1.zip: piwigo/plugins/c13y_upgrade/language/pt_BR/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['c13y_correction_dbl_email_user'] = 'Eliminar usuários duplicados';
$lang['c13y_correction_obsolete_plugin'] = 'plugin "%s" foi incluído nesta versão do aplicativo e você deve desinstalá-lo.';
$lang['c13y_dbl_email_user'] = 'Usuários com o mesmo endereço de email';
$lang['c13y_obsolete_plugin'] = 'Plugin obsoleto';
$lang['c13y_upgrade_no_anomaly'] = 'Nenhuma anomalia detectada após a atualização do aplicativo, "Verificar atualizações" plugin foi desativado.';
?>

==> piwigo-2.5.3.zip: piwigo/plugins/c13y_upgrade/language/pt_BR/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['c13y_correction_dbl_email_user'] = 'Eliminar usuários duplicados';
$lang['c13y_correction_obsolete_plugin'] = 'plugin "%s" foi incluído nesta versão do aplicativo e você deve desinstalá-lo.';
$lang['c13y_dbl_email_user'] = 'Usuários com o mesmo endereço de email';
$lang['c13y_obsolete_plugin'] = 'Plugin obsoleto';
$lang['c13y_upgrade_no_anomaly'] = 'Nenhuma anomalia foi detectada após a atualização do aplicativo, o plugin "Verificar atualizações" foi desativado.';
?>
